Documentation
¶
Overview ¶
package Factis provides a thread-safe object that can be used for responsible state tracking across multi-step test scenarios.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Factis ¶
type Factis struct {
// contains filtered or unexported fields
}
Factis is a collection of facts. It is thread-safe. It is used to store facts that are shared between steps.
func From ¶
From returns the factis stored in the given interface. It returns an error if the given interface is not a Factis.
func (*Factis) Forget ¶
Forget removes the fact stored under the given name. If Factis does not know the fact, it returns an error.
func (*Factis) Memorize ¶
Memorize stores the given fact under the given name. If Factis already knows the fact, it returns an error.
Click to show internal directories.
Click to hide internal directories.